#!/usr/bin/env bash
#
# Skinny wrapper environment script for ACSPO (acspo.R) under CSPP with singularity
#
# The location of the singularity container is required.
# So I am going to require CSPP_ACSPO_HOME to find it.
#
# exit when the first non-zero exit status is encountered
set -e

# check installation home and chdir to it
if [[ -z $CSPP_ACSPO_HOME ]]; then
  echo "Must provide CSPP_ACSPO_HOME in environment. See cspp_acspo_env.sh" 1>&2
  exit 1
fi

# check for singularity 
$CSPP_ACSPO_HOME/scripts/sing_test.bash

# check the container location; ascpo.sif is version packaged with squashfs system
if [[ -f $CSPP_ACSPO_HOME/acspo.sif ]] ; then
  container=$CSPP_ACSPO_HOME/acspo.sif
else
  container=$CSPP_ACSPO_HOME/lib/s2i-acspo-run-centos7.sif
fi

# figure the lowest common factor bind string that is NOT /

# PROBLEM:
# + bind='--bind /dev,/proc,/run,/data'
#sbind=$(singularity --silent exec --home $(readlink -f "$PWD") --bind $CSPP_ACSPO_HOME $container Rscript $CSPP_ACSPO_HOME/scripts/bind_wrangle.R $@)
#echo "sbind: $sbind"

bind=$($CSPP_ACSPO_HOME/scripts/bind_wrangle.bash $@)
#echo "bind: $bind"

# run acspo.R in the provided singularity container
singularity --silent exec --home $PWD $bind $container Rscript $CSPP_ACSPO_HOME/scripts/acspo.R $@

# Done
echo Done.
